import { Multilingual } from "@/data/common";

interface PredefinedChoices {
    choices: Multilingual<string>[];
}

export interface BaseFieldDefinition {
    name: string;
    description: Multilingual<string>;
    label: Multilingual<string>;
}

export interface TextFieldDefinition extends BaseFieldDefinition {
    type: "short-text" | "long-text";
}

export type TextFieldValue = string;

export interface MultiChoiceFieldDefinition extends BaseFieldDefinition, PredefinedChoices {
    type: "checkbox";
}

export type MultiChoiceValue = Multilingual<string>[];

export interface SingleChoiceFieldDefinition extends BaseFieldDefinition, PredefinedChoices {
    type: "radio" | "select";
}

export type SingleChoiceValue = Multilingual<string>;

export type ReportFieldDefinition = TextFieldDefinition | MultiChoiceFieldDefinition | SingleChoiceFieldDefinition;
export type ReportFieldValue = TextFieldValue | MultiChoiceValue | SingleChoiceValue;
export type ReportFieldValues = { [field: string]: ReportFieldValue };
export type ReportSchema = ReportFieldDefinition[];

export interface Report {
    fields: ReportFieldValues;
}

export const reportFieldTypes = ["short-text", "long-text", "checkbox", "radio", "select"];

