import React from "react";
import { Button, Dialog, DialogActions, DialogContent, DialogProps, DialogTitle } from "@material-ui/core";
import { ReportFieldDefinition } from "@/data/report";
import { useTranslation } from "react-i18next";
import { useSpacing } from "@/styles";
import { Form, Formik } from "formik";
import { Actions } from "@/components";
import { Save } from "@material-ui/icons";
import { Cancel } from "mdi-material-ui";
import { FieldDefinitionForm, FieldDefinitionFormValues, fieldFormValuesTransformer, initialFieldFormValues } from "@/management/edition/report/fields/form";

export type EditFieldDialogProps = {
    onSave?: (field: ReportFieldDefinition) => void;
    field?: ReportFieldDefinition;
} & DialogProps;

export function EditFieldDefinitionDialog({ onSave, field, ...props }: EditFieldDialogProps) {
    const { t } = useTranslation("management");
    const spacing = useSpacing(3);

    const handleSubmit = (values: FieldDefinitionFormValues) => {
        onSave?.(fieldFormValuesTransformer.reverseTransform(values));
    };

    const initialValues = field
        ? fieldFormValuesTransformer.transform(field)
        : initialFieldFormValues;

    return <Dialog { ...props } maxWidth="md">
        <Formik initialValues={ initialValues } onSubmit={ handleSubmit }>
            <Form className={ spacing.vertical }>
                <DialogTitle>{ t(field ? "report-field.edit.title" : "report-field.create.title") }</DialogTitle>
                <DialogContent>
                    <FieldDefinitionForm />
                </DialogContent>
                <DialogActions>
                    <Actions>
                        <Button variant="contained" color="primary" startIcon={ <Save /> } type="submit">{ t("save") }</Button>
                        <Button startIcon={ <Cancel /> } onClick={ ev => props.onClose?.(ev, "escapeKeyDown") }>{ t("cancel") }</Button>
                    </Actions>
                </DialogActions>
            </Form>
        </Formik>
    </Dialog>
}
