import { Route } from "@/routing";
import { isManagerMiddleware } from "@/management/middleware";
import { EditionsManagement } from "@/management/edition/list";
import React from "react";
import { ManagementIndex } from "@/management/main";
import StaticPageManagement from "@/management/page/list";
import { InternshipTypeManagement } from "@/management/type/list";
import { EditionRouter, EditionManagement } from "@/management/edition/manage";
import { EditionReportFields } from "@/management/edition/report/fields/list";
import { EditionSettings } from "@/management/edition/settings";

export const managementRoutes: Route[] = ([
    { name: "index", path: "/", content: ManagementIndex, exact: true },

    { name: "edition_router", path: "/editions/:edition", content: EditionRouter },
    { name: "edition_report_form", path: "/editions/:edition/report", content: EditionReportFields, tags: ["edition"] },
    { name: "edition_settings", path: "/editions/:edition/settings", content: EditionSettings, tags: ["edition"] },
    { name: "edition_manage", path: "/editions/:edition", content: EditionManagement, tags: ["edition"] },
    { name: "editions", path: "/editions", content: EditionsManagement },

    { name: "types", path: "/types", content: InternshipTypeManagement },
    { name: "static_pages", path: "/static-pages", content: StaticPageManagement }
] as Route[]).map(
    ({ name, path, middlewares = [], ...route }): Route => ({
        name: `management:${ name }`,
        path: `/management${ path }`,
        middlewares: [ isManagerMiddleware, ...middlewares ],
        ...route
    })
);
