import React from "react";
import { InternshipType } from "@/data";
import { useTranslation } from "react-i18next";
import { useSpacing } from "@/styles";
import { Field } from "formik";
import { TextField as TextFieldFormik, Checkbox as CheckboxFormik } from "formik-material-ui";
import { FormControlLabel, FormGroup, Typography } from "@material-ui/core";
import { CKEditorField } from "@/field/ckeditor";
import { AccountCheck, ShieldCheck } from "mdi-material-ui";
import { identityTransformer, Transformer } from "@/serialization";
import { LabelWithIcon } from "@/management/common/LabelWithIcon";

export type InternshipTypeFormValues = Omit<InternshipType, 'id'>;

export const initialInternshipTypeFormValues: InternshipTypeFormValues = {
    label: {
        pl: "",
        en: "",
    },
    description: {
        pl: "",
        en: "",
    },
    requiresInsurance: false,
    requiresDeanApproval: false,
}

export const internshipTypeFormValuesTransformer: Transformer<InternshipType, InternshipTypeFormValues> = identityTransformer;

export function InternshipTypeForm() {
    const { t } = useTranslation("management");
    const spacing = useSpacing(2);

    return <div className={ spacing.vertical }>
        <Typography variant="subtitle2">{ t("type.field.label") }</Typography>
        <Field label={ t("translation:language.pl") } name="label.pl" fullWidth component={ TextFieldFormik }/>
        <Field label={ t("translation:language.en") } name="label.en" fullWidth component={ TextFieldFormik }/>
        <Typography variant="subtitle2">{ t("type.field.description") }</Typography>
        <Field label={ t("translation:language.pl") } name="description.pl" fullWidth component={ TextFieldFormik }/>
        <Field label={ t("translation:language.en") } name="description.en" fullWidth component={ TextFieldFormik }/>

        <Typography variant="subtitle2">{ t("type.field.flags") }</Typography>
        <FormGroup>
            <FormControlLabel
                control={ <Field name="requiresDeanApproval" component={ CheckboxFormik }/> }
                label={ <LabelWithIcon icon={ <AccountCheck /> }>{ t("type.flag.dean-approval") }</LabelWithIcon> }
            />
            <FormControlLabel
                control={ <Field name="requiresInsurance" component={ CheckboxFormik }/> }
                label={ <LabelWithIcon icon={ <ShieldCheck /> }>{ t("type.flag.insurance") }</LabelWithIcon> }
            />
        </FormGroup>
    </div>

}
